@@ -39,8 +39,9 @@ class PrintData:
 class PrintHandler:
     """Handler for the CherryTree Prints"""
 
-    def __init__(self):
+    def __init__(self, dad):
         """Instantiate Variables"""
+        self.dad = dad
         self.active_prints = []
         self.settings = None
         self.page_setup = None
@@ -95,6 +96,12 @@ class PrintHandler:
         """Here we Compute the Lines Positions, the Number of Pages Needed and the Page Breaks"""
         self.page_width = context.get_width()
         self.page_height = context.get_height() * 1.02 # tolerance at bottom of the page
+        any_image_resized = False
+        layout_newline = context.create_pango_layout()
+        layout_newline.set_font_description(self.pango_font)
+        layout_newline.set_width(int(self.page_width*pango.SCALE))
+        layout_newline.set_markup(cons.CHAR_NEWLINE)
+        line_width, self.layout_newline_height = self.layout_line_get_width_height(layout_newline.get_line(0))
         while 1:
             exit_ok = True
             print_data.layout = []
@@ -111,8 +118,11 @@ class PrintHandler:
                 print_data.forced_page_break.append(is_forced_page_break)
                 print_data.layout[-1].set_markup(text_slot if not is_forced_page_break else text_slot[2:])
                 if text_slot == cons.CHAR_NEWLINE:
-                    print_data.layout_is_new_line.append(True) # in other case we detect the newline from a following line
-                else: print_data.layout_is_new_line.append(False) # but here we have a single layout line
+                    # in other cases we detect the newline from a following line
+                    # but here we have a single layout line
+                    print_data.layout_is_new_line.append(True)
+                else:
+                    print_data.layout_is_new_line.append(False)
                 print_data.layout_num_lines.append(print_data.layout[-1].get_line_count())
             self.y_idx = 0
             print_data.page_breaks = []
@@ -144,6 +154,11 @@ class PrintHandler:
                                     self.codebox_long_split(i-1, context, print_data)
                                     exit_ok = False
                                     break # go to a new main loop
+                                elif self.pixbuf_table_codebox_vector[i-1][0] == "table"\
+                                and table_height > self.page_height:
+                                    self.table_long_split(i-1, context, print_data)
+                                    exit_ok = False
+                                    break # go to a new main loop
                         curr_y += inline_pending_height
                         print_data.all_lines_y.append(curr_y)
                         #print "added line y <%s> (%s, %s)" % (curr_y, i, layout_line_idx)
@@ -162,19 +177,20 @@ class PrintHandler:
                             image_w_h_ration = float(pixbuf_width)/pixbuf_height
                             image_width = self.page_width
                             image_height = image_width / image_w_h_ration
-                            pixbuf = pixbuf.scale_simple(int(image_width),
-                                                         int(image_height),
-                                                         gtk.gdk.INTERP_BILINEAR)
+                            pixbuf = pixbuf.scale_simple(int(image_width), int(image_height), gtk.gdk.INTERP_BILINEAR)
+                            pixbuf_width = pixbuf.get_width()
+                            pixbuf_height = pixbuf.get_height()
                             pixbuf_was_resized = True
-                        if pixbuf_height > self.page_height:
+                        if pixbuf_height > (self.page_height-self.layout_newline_height-cons.WHITE_SPACE_BETW_PIXB_AND_TEXT):
                             image_w_h_ration = float(pixbuf_width)/pixbuf_height
-                            image_height = self.page_height
+                            image_height = self.page_height-self.layout_newline_height-cons.WHITE_SPACE_BETW_PIXB_AND_TEXT
                             image_width = image_height * image_w_h_ration
-                            pixbuf = pixbuf.scale_simple(int(image_width),
-                                                         int(image_height),
-                                                         gtk.gdk.INTERP_BILINEAR)
+                            pixbuf = pixbuf.scale_simple(int(image_width), int(image_height), gtk.gdk.INTERP_BILINEAR)
+                            pixbuf_width = pixbuf.get_width()
+                            pixbuf_height = pixbuf.get_height()
                             pixbuf_was_resized = True
                         if pixbuf_was_resized:
+                            any_image_resized = True
                             self.pixbuf_table_codebox_vector[i][1][1] = pixbuf
                         pixbuf_height = pixbuf.get_height() + cons.WHITE_SPACE_BETW_PIXB_AND_TEXT
                         if inline_pending_height < pixbuf_height: inline_pending_height = pixbuf_height
@@ -192,6 +208,9 @@ class PrintHandler:
                         if inline_pending_height < codebox_height+BOX_OFFSET: inline_pending_height = codebox_height+BOX_OFFSET
             if exit_ok: break
         operation.set_n_pages(len(print_data.page_breaks) + 1)
+        if any_image_resized:
+            self.dad.statusbar.pop(self.dad.statusbar_context_id)
+            self.dad.statusbar.push(self.dad.statusbar_context_id, _("Warning: One or More Images Were Reduced to Enter the Page")+" (%sx%s)" % (int(self.page_width), int(self.page_height)))
 
     def on_draw_page_text(self, operation, context, page_nr, print_data):
         """This Function is Called For Each Page Set in on_begin_print_text"""
@@ -418,33 +437,63 @@ class PrintHandler:
             y += line_height
             cairo_context.show_layout_line(layout_line)
 
+    def table_long_split(self, idx, context, print_data):
+        """Split Long Tables"""
+        table_dict = self.pixbuf_table_codebox_vector[idx][1][1]
+        table_dict_jolly = copy.deepcopy(table_dict)
+        partial_table_matrix_vec = []
+        partial_table_matrix = [copy.deepcopy(table_dict['matrix'][0])]
+        while len(partial_table_matrix) < len(table_dict['matrix']):
+            partial_table_matrix.append(copy.deepcopy(table_dict['matrix'][len(partial_table_matrix)]))
+            table_dict_jolly['matrix'] = partial_table_matrix
+            table_layouts = self.get_table_layouts(context, table_dict_jolly)
+            table_grid = self.get_table_grid(table_layouts, table_dict_jolly['col_min'])
+            table_height = self.get_table_height_from_grid(table_grid)
+            if table_height+BOX_OFFSET > (self.page_height-self.layout_newline_height):
+                # this slot is done
+                partial_table_matrix.pop()
+                partial_table_matrix_vec.append(partial_table_matrix)
+                table_dict['matrix'] = table_dict['matrix'][len(partial_table_matrix):]
+                table_dict['matrix'].insert(0, copy.deepcopy(partial_table_matrix[0]))
+                partial_table_matrix = [copy.deepcopy(table_dict['matrix'][0])]
+        # this is the last piece
+        partial_table_matrix_vec.append(partial_table_matrix)
+        for i, element in enumerate(partial_table_matrix_vec):
+            #print i, element
+            if i == 0: table_dict['matrix'] = element[1:] + [element[0]]
+            else:
+                index = idx+i
+                # add a newline
+                print_data.text.insert(index, cons.CHAR_NEWLINE)
+                # add a codebox
+                new_table_dict = copy.deepcopy(table_dict)
+                new_table_dict['matrix'] = element[1:] + [element[0]]
+                pixbuf_table_codebox_element = ["table", [None, new_table_dict, None]]
+                self.pixbuf_table_codebox_vector.insert(index, pixbuf_table_codebox_element)
+
     def codebox_long_split(self, idx, context, print_data):
         """Split Long CodeBoxes"""
         codebox_dict = self.pixbuf_table_codebox_vector[idx][1][1]
         original_splitted_pango = codebox_dict['fill_text'].split(cons.CHAR_NEWLINE)
-        splitted_pango = copy.deepcopy(original_splitted_pango)
+        splitted_pango = []
         codebox_dict_jolly = copy.deepcopy(codebox_dict)
         partial_pango_vec = []
-        while len(splitted_pango) > 1:
-            splitted_pango = splitted_pango[:-1]
+        partial_pango = ""
+        partial_pango_old = ""
+        while len(splitted_pango) < len(original_splitted_pango):
+            splitted_pango.append(original_splitted_pango[len(splitted_pango)])
+            if partial_pango: partial_pango_old = partial_pango
             partial_pango = cons.CHAR_NEWLINE.join(splitted_pango)
             codebox_dict_jolly['fill_text'] = partial_pango
             codebox_layout = self.get_codebox_layout(context, codebox_dict_jolly)
             codebox_height = self.get_height_from_layout(codebox_layout)
-            if codebox_height < self.page_height:
+            if codebox_height+BOX_OFFSET > (self.page_height-self.layout_newline_height):
                 # this slot is done
-                partial_pango_vec.append(partial_pango)
-                # let's get ready for the next slot
-                splitted_pango = original_splitted_pango[len(splitted_pango):]
-                original_splitted_pango = splitted_pango
-                partial_pango = cons.CHAR_NEWLINE.join(splitted_pango)
-                codebox_dict_jolly['fill_text'] = partial_pango
-                codebox_layout = self.get_codebox_layout(context, codebox_dict_jolly)
-                codebox_height = self.get_height_from_layout(codebox_layout)
-                if codebox_height < self.page_height:
-                    # this is the last piece
-                    partial_pango_vec.append(partial_pango)
-                    break
+                partial_pango_vec.append(partial_pango_old)
+                original_splitted_pango = original_splitted_pango[len(splitted_pango)-1:]
+                splitted_pango = []
+        # this is the last piece
+        partial_pango_vec.append(partial_pango)
         for i, element in enumerate(partial_pango_vec):
             if i == 0: codebox_dict['fill_text'] = element
             else:
